@@ -5,10 +5,57 @@ from pathlib import Path
 from random import randint
 
 
-class InvalidFileIOCall(Exception):
+class Error(Exception):
     pass
 
 
+# noinspection PySameParameterValue
+class InvalidFileIOCall(Error):
+    def __init__(self, *args):
+        if args:
+            self.message = args[0]
+        else:
+            self.message = None
+        try:
+            self.io = args[1]
+        except IndexError:
+            self.io = None
+
+    def __str__(self):
+        if self.message:
+            return '\nInvalidFileIOCall {0} "{1}" '.format(self.message, self.io)
+        else:
+            return 'InvalidFileIOCall has been raised'
+
+
+class DataMustBeNone(Error):
+    def __init__(self, *args):
+        if args:
+            self.io = args[0]
+        else:
+            self.io = None
+
+    def __str__(self):
+        if self.io:
+            return 'Data must be None on option "{0}"'.format(self.io)
+        else:
+            return 'Data must be None on option -> "check" or "load"'
+
+
+class DataCantBeNone(Error):
+    def __init__(self, *args):
+        if args:
+            self.io = args[0]
+        else:
+            self.io = None
+
+    def __str__(self):
+        if self.io:
+            return 'Data can\'t be None on option "{0}"'.format(self.io)
+        else:
+            return 'Data can\'t be None on option -> "save"'
+
+
 class FileIO:
     def __init__(self, filepath, io, data=None):
         self.filepath = filepath
@@ -16,22 +63,31 @@ class FileIO:
         self.data = data
 
     @staticmethod
-    def fileio(filepath, io, data=None):
+    def fileio(filepath, option, data=None):
         """
-
         :param filepath: Full Filepath including Filename
-        :param io: action [save, load, check]
+        :param option: action [save, load, check]
         :param data: json formatted data to save
         :return:
         """
-        if io == "save" and data is not None:
-            return FileIO.save_json(filepath, data)
-        elif io == "load" and data is None:
-            return FileIO._read_json(filepath)
-        elif io == "check" and data is None:
-            return FileIO.is_valid_json(filepath)
+        if option == "save":
+            if data is not None:
+                return FileIO.save_json(filepath, data)
+            else:
+                raise DataCantBeNone(option)
+        elif option == "load":
+            if data is None:
+                return FileIO._read_json(filepath)
+            else:
+                raise DataMustBeNone(option)
+        elif option == "check":
+            if data is None:
+                return FileIO.is_valid_json(filepath)
+            else:
+                raise DataMustBeNone(option)
         else:
-            raise InvalidFileIOCall("FileIO was called with invalid parameters")
+            raise InvalidFileIOCall("FileIO was called with invalid parameter\n"
+                                    "Allowed parameters are: 'save', 'load', and 'check'", option)
 
     @staticmethod
     def is_valid_json(filepath):
